@@ -1,20 +1,19 @@
-"""
-PSUtils libpaper interface.
-Copyright (c) Reuben Thomas 2023.
+"""PSUtils libpaper interface.
+
+Copyright (c) Reuben Thomas 2023-2025.
 Released under the GPL version 3, or (at your option) any later version.
 """
 
 import os
-import subprocess
 import re
-from typing import List, Optional
+import subprocess
 
 from .types import Rectangle
 from .warnings import die
 
 
 # Get the size of the given paper, or the default paper if no argument given.
-def paper(cmd: List[str], silent: bool = False) -> Optional[str]:
+def paper(cmd: list[str], silent: bool = False) -> str | None:
     cmd.insert(0, "paper")
     try:
         out = subprocess.check_output(
@@ -26,14 +25,14 @@ def paper(cmd: List[str], silent: bool = False) -> Optional[str]:
         return out.rstrip()
     except subprocess.CalledProcessError:
         return None
-    except:  # pylint: disable=bare-except
+    except Exception:
         die("could not run `paper' command")
 
 
-def get_paper_size(paper_name: Optional[str] = None) -> Optional[Rectangle]:
+def get_paper_size(paper_name: str | None = None) -> Rectangle | None:
     if paper_name is None:
         paper_name = paper(["--no-size"])
-    dimensions: Optional[str] = None
+    dimensions: str | None = None
     if paper_name is not None:
         dimensions = paper(["--unit=pt", paper_name], True)
     if dimensions is None:
