@@ -1,5 +1,5 @@
-"""
-PSUtils utilities for dealing with PostScript Resources.
+"""PSUtils utilities for dealing with PostScript Resources.
+
 Copyright (c) Reuben Thomas 2023.
 Released under the GPL version 3, or (at your option) any later version.
 """
